# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/gateway/redispoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from mapped.cloud.types import typed_value_pb2 as mapped_dot_cloud_dot_types_dot_typed__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmapped/gateway/redispoint.proto\x12\x0emapped.gateway\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$mapped/cloud/types/typed_value.proto\"\xa1\x02\n\nRedisPoint\x12\x43\n\rpresent_value\x18\x01 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x0cpresentValue\x12;\n\x0blast_update\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUpdate\x12J\n\x13network_error_start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11networkErrorStart\x12\x45\n\x1f\x63onsecutive_network_error_count\x18\x04 \x01(\rR\x1c\x63onsecutiveNetworkErrorCountBI\n\x12\x63om.mapped.gatewayP\x01Z go.mapped.dev/pb/gateway;gateway\xaa\x02\x0eMapped.Gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.gateway.redispoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.mapped.gatewayP\001Z go.mapped.dev/pb/gateway;gateway\252\002\016Mapped.Gateway'
  _REDISPOINT._serialized_start=123
  _REDISPOINT._serialized_end=412
# @@protoc_insertion_point(module_scope)
