# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/typed_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from mapped.cloud.types import calendar_period_pb2 as mapped_dot_cloud_dot_types_dot_calendar__period__pb2
from mapped.cloud.types import date_pb2 as mapped_dot_cloud_dot_types_dot_date__pb2
from mapped.cloud.types import dayofweek_pb2 as mapped_dot_cloud_dot_types_dot_dayofweek__pb2
from mapped.cloud.types import interval_pb2 as mapped_dot_cloud_dot_types_dot_interval__pb2
from mapped.cloud.types import money_pb2 as mapped_dot_cloud_dot_types_dot_money__pb2
from mapped.cloud.types import month_pb2 as mapped_dot_cloud_dot_types_dot_month__pb2
from mapped.cloud.types import phone_number_pb2 as mapped_dot_cloud_dot_types_dot_phone__number__pb2
from mapped.cloud.types import postal_address_pb2 as mapped_dot_cloud_dot_types_dot_postal__address__pb2
from mapped.cloud.types import timeofday_pb2 as mapped_dot_cloud_dot_types_dot_timeofday__pb2
from mapped.cloud.types import geojson_pb2 as mapped_dot_cloud_dot_types_dot_geojson__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$mapped/cloud/types/typed_value.proto\x12\x12mapped.cloud.types\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(mapped/cloud/types/calendar_period.proto\x1a\x1dmapped/cloud/types/date.proto\x1a\"mapped/cloud/types/dayofweek.proto\x1a!mapped/cloud/types/interval.proto\x1a\x1emapped/cloud/types/money.proto\x1a\x1emapped/cloud/types/month.proto\x1a%mapped/cloud/types/phone_number.proto\x1a\'mapped/cloud/types/postal_address.proto\x1a\"mapped/cloud/types/timeofday.proto\x1a mapped/cloud/types/geojson.proto\"\'\n\x11\x43ontextLinkedData\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\"\x80\x01\n\rAnyLinkedData\x12@\n\x07\x63ontext\x18\x01 \x01(\x0b\x32%.mapped.cloud.types.ContextLinkedDataR\x08@context\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x05value\"\xae\x01\n\x10\x41nyLinkedDataMap\x12?\n\x03map\x18\x01 \x03(\x0b\x32-.mapped.cloud.types.AnyLinkedDataMap.MapEntryR\x03map\x1aY\n\x08MapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32!.mapped.cloud.types.AnyLinkedDataR\x05value:\x02\x38\x01\"\xc9\x0b\n\nTypedValue\x12\x1f\n\nbool_value\x18\n \x01(\x08H\x00R\tboolValue\x12#\n\x0cuint32_value\x18\x0b \x01(\rH\x00R\x0buint32Value\x12#\n\x0cuint64_value\x18\x0c \x01(\x04H\x00R\x0buint64Value\x12!\n\x0bint32_value\x18\r \x01(\x05H\x00R\nint32Value\x12!\n\x0bint64_value\x18\x0e \x01(\x03H\x00R\nint64Value\x12%\n\rfloat32_value\x18\x0f \x01(\x02H\x00R\x0c\x66loat32Value\x12%\n\rfloat64_value\x18\x10 \x01(\x01H\x00R\x0c\x66loat64Value\x12*\n\x10\x62yte_array_value\x18\x11 \x01(\x0cH\x00R\x0e\x62yteArrayValue\x12#\n\x0cstring_value\x18\x12 \x01(\tH\x00R\x0bstringValue\x12\x1f\n\nuuid_value\x18\x13 \x01(\x0cH\x00R\tuuidValue\x12I\n\x10\x62ool_array_value\x18\x14 \x01(\x0b\x32\x1d.mapped.cloud.types.BoolArrayH\x00R\x0e\x62oolArrayValue\x12\x1f\n\nenum_value\x18\x15 \x01(\rH\x00R\tenumValue\x12\x39\n\ndate_value\x18\x16 \x01(\x0b\x32\x18.mapped.cloud.types.DateH\x00R\tdateValue\x12>\n\ntime_value\x18\x17 \x01(\x0b\x32\x1d.mapped.cloud.types.TimeOfDayH\x00R\ttimeValue\x12\x45\n\x0ftimestamp_value\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x0etimestampValue\x12>\n\rgeojson_value\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0cgeojsonValue\x12\x45\n\x0egeopoint_value\x18\x1c \x01(\x0b\x32\x1c.mapped.cloud.types.GeoPointH\x00R\rgeopointValue\x12\x37\n\x04json\x18\x1d \x01(\x0b\x32!.mapped.cloud.types.AnyLinkedDataH\x00R\x04json\x12\x42\n\tmap_value\x18\x1e \x01(\x0b\x32#.mapped.cloud.types.GenericTypedMapH\x00R\x08mapValue\x12X\n\x15\x63\x61lendar_period_value\x18\x64 \x01(\x0e\x32\".mapped.cloud.types.CalendarPeriodH\x00R\x13\x63\x61lendarPeriodValue\x12J\n\x11\x64\x61y_of_week_value\x18\x65 \x01(\x0e\x32\x1d.mapped.cloud.types.DayOfWeekH\x00R\x0e\x64\x61yOfWeekValue\x12\x45\n\x0einterval_value\x18\x66 \x01(\x0b\x32\x1c.mapped.cloud.types.IntervalH\x00R\rintervalValue\x12<\n\x0bmoney_value\x18g \x01(\x0b\x32\x19.mapped.cloud.types.MoneyH\x00R\nmoneyValue\x12<\n\x0bmonth_value\x18h \x01(\x0e\x32\x19.mapped.cloud.types.MonthH\x00R\nmonthValue\x12O\n\x12phone_number_value\x18i \x01(\x0b\x32\x1f.mapped.cloud.types.PhoneNumberH\x00R\x10phoneNumberValue\x12U\n\x14postal_address_value\x18j \x01(\x0b\x32!.mapped.cloud.types.PostalAddressH\x00R\x12postalAddressValueB\x07\n\x05value\"\xa5\x01\n\rTypedValueMap\x12<\n\x03map\x18\x01 \x03(\x0b\x32*.mapped.cloud.types.TypedValueMap.MapEntryR\x03map\x1aV\n\x08MapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value:\x02\x38\x01\"\xc7\x01\n\x0fGenericTypedMap\x12\x43\n\x07\x65ntries\x18\x01 \x03(\x0b\x32).mapped.cloud.types.GenericTypedMap.EntryR\x07\x65ntries\x1ao\n\x05\x45ntry\x12\x30\n\x03key\x18\x01 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value\"#\n\tBoolArray\x12\x16\n\x06values\x18\x01 \x03(\x08R\x06valuesBS\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.typed_value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\252\002\022Mapped.Cloud.Types'
  _ANYLINKEDDATAMAP_MAPENTRY._options = None
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_options = b'8\001'
  _TYPEDVALUEMAP_MAPENTRY._options = None
  _TYPEDVALUEMAP_MAPENTRY._serialized_options = b'8\001'
  _CONTEXTLINKEDDATA._serialized_start=481
  _CONTEXTLINKEDDATA._serialized_end=520
  _ANYLINKEDDATA._serialized_start=523
  _ANYLINKEDDATA._serialized_end=651
  _ANYLINKEDDATAMAP._serialized_start=654
  _ANYLINKEDDATAMAP._serialized_end=828
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_start=739
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_end=828
  _TYPEDVALUE._serialized_start=831
  _TYPEDVALUE._serialized_end=2312
  _TYPEDVALUEMAP._serialized_start=2315
  _TYPEDVALUEMAP._serialized_end=2480
  _TYPEDVALUEMAP_MAPENTRY._serialized_start=2394
  _TYPEDVALUEMAP_MAPENTRY._serialized_end=2480
  _GENERICTYPEDMAP._serialized_start=2483
  _GENERICTYPEDMAP._serialized_end=2682
  _GENERICTYPEDMAP_ENTRY._serialized_start=2571
  _GENERICTYPEDMAP_ENTRY._serialized_end=2682
  _BOOLARRAY._serialized_start=2684
  _BOOLARRAY._serialized_end=2719
# @@protoc_insertion_point(module_scope)
