# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/timeofday.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"mapped/cloud/types/timeofday.proto\x12\x12mapped.cloud.types\"k\n\tTimeOfDay\x12\x14\n\x05hours\x18\x01 \x01(\x05R\x05hours\x12\x18\n\x07minutes\x18\x02 \x01(\x05R\x07minutes\x12\x18\n\x07seconds\x18\x03 \x01(\x05R\x07seconds\x12\x14\n\x05nanos\x18\x04 \x01(\x05R\x05nanosBf\n\x16\x63om.mapped.cloud.typesB\x0eTimeOfDayProtoP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.timeofday_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesB\016TimeOfDayProtoP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _TIMEOFDAY._serialized_start=58
  _TIMEOFDAY._serialized_end=165
# @@protoc_insertion_point(module_scope)
