# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/postal_address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'mapped/cloud/types/postal_address.proto\x12\x12mapped.cloud.types\"\x8d\x03\n\rPostalAddress\x12\x1a\n\x08revision\x18\x01 \x01(\x05R\x08revision\x12\x1f\n\x0bregion_code\x18\x02 \x01(\tR\nregionCode\x12#\n\rlanguage_code\x18\x03 \x01(\tR\x0clanguageCode\x12\x1f\n\x0bpostal_code\x18\x04 \x01(\tR\npostalCode\x12!\n\x0csorting_code\x18\x05 \x01(\tR\x0bsortingCode\x12/\n\x13\x61\x64ministrative_area\x18\x06 \x01(\tR\x12\x61\x64ministrativeArea\x12\x1a\n\x08locality\x18\x07 \x01(\tR\x08locality\x12 \n\x0bsublocality\x18\x08 \x01(\tR\x0bsublocality\x12#\n\raddress_lines\x18\t \x03(\tR\x0c\x61\x64\x64ressLines\x12\x1e\n\nrecipients\x18\n \x03(\tR\nrecipients\x12\"\n\x0corganization\x18\x0b \x01(\tR\x0corganizationBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.postal_address_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _POSTALADDRESS._serialized_start=64
  _POSTALADDRESS._serialized_end=461
# @@protoc_insertion_point(module_scope)
