# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/phone_number.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%mapped/cloud/types/phone_number.proto\x12\x12mapped.cloud.types\"\xe8\x01\n\x0bPhoneNumber\x12!\n\x0b\x65\x31\x36\x34_number\x18\x01 \x01(\tH\x00R\ne164Number\x12J\n\nshort_code\x18\x02 \x01(\x0b\x32).mapped.cloud.types.PhoneNumber.ShortCodeH\x00R\tshortCode\x12\x1c\n\textension\x18\x03 \x01(\tR\textension\x1a\x44\n\tShortCode\x12\x1f\n\x0bregion_code\x18\x01 \x01(\tR\nregionCode\x12\x16\n\x06number\x18\x02 \x01(\tR\x06numberB\x06\n\x04kindBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.phone_number_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _PHONENUMBER._serialized_start=62
  _PHONENUMBER._serialized_end=294
  _PHONENUMBER_SHORTCODE._serialized_start=218
  _PHONENUMBER_SHORTCODE._serialized_end=286
# @@protoc_insertion_point(module_scope)
