# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/calendar_period.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(mapped/cloud/types/calendar_period.proto\x12\x12mapped.cloud.types*\x7f\n\x0e\x43\x61lendarPeriod\x12\x1f\n\x1b\x43\x41LENDAR_PERIOD_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x08\n\x04WEEK\x10\x02\x12\r\n\tFORTNIGHT\x10\x03\x12\t\n\x05MONTH\x10\x04\x12\x0b\n\x07QUARTER\x10\x05\x12\x08\n\x04HALF\x10\x06\x12\x08\n\x04YEAR\x10\x07\x42V\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.calendar_period_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _CALENDARPERIOD._serialized_start=64
  _CALENDARPERIOD._serialized_end=191
# @@protoc_insertion_point(module_scope)
