# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/gateway/edgecontrol.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mapped.cloud.types import typed_value_pb2 as mapped_dot_cloud_dot_types_dot_typed__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n mapped/gateway/edgecontrol.proto\x12\x0emapped.gateway\x1a$mapped/cloud/types/typed_value.proto\"\xa3\x01\n\x11WritePropsRequest\x12:\n\x06values\x18\x01 \x03(\x0b\x32\".mapped.gateway.MappingKeyAndValueR\x06values\x12\x36\n\x18timeout_per_device_in_ms\x18\x02 \x01(\rR\x14timeoutPerDeviceInMs\x12\x1a\n\x08simulate\x18\x64 \x01(\x08R\x08simulate\"r\n\x12WritePropsResponse\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12=\n\x07results\x18\x02 \x03(\x0b\x32#.mapped.gateway.MappingKeyAndResultR\x07results\"k\n\x12MappingKeyAndValue\x12\x1f\n\x0bmapping_key\x18\x01 \x01(\tR\nmappingKey\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value\"\xf5\x01\n\x13MappingKeyAndResult\x12\x1f\n\x0bmapping_key\x18\x01 \x01(\tR\nmappingKey\x12.\n\x06result\x18\x02 \x01(\x0e\x32\x16.mapped.gateway.ResultR\x06result\x12+\n\x11\x65rror_description\x18\x03 \x01(\tR\x10\x65rrorDescription\x12\x30\n\x14protocol_error_class\x18\x04 \x01(\x03R\x12protocolErrorClass\x12.\n\x13protocol_error_code\x18\x05 \x01(\x03R\x11protocolErrorCode*\xcc\x03\n\x06Result\x12\x16\n\x12RESULT_UNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rERROR_UNKNOWN\x10\x64\x12\x1d\n\x19\x45RROR_UNKNOWN_MAPPING_KEY\x10\x65\x12\x11\n\rERROR_TIMEOUT\x10g\x12\x1a\n\x16\x45RROR_HOST_UNREACHABLE\x10h\x12\x1b\n\x17\x45RROR_VALUE_TYPE_CHANGE\x10x\x12#\n\x1f\x45RROR_VALUE_ARRAY_INDEX_INVALID\x10y\x12\x1c\n\x18\x45RROR_VALUE_TYPE_INVALID\x10z\x12 \n\x1c\x45RROR_VALUE_TYPE_UNSUPPORTED\x10{\x12\x19\n\x15\x45RROR_VALUE_NOT_ARRAY\x10|\x12\x1c\n\x18\x45RROR_VALUE_OUT_OF_RANGE\x10}\x12#\n\x1f\x45RROR_VALUE_WRITE_ACCESS_DENIED\x10~\x12\x17\n\x12\x45RROR_DEVICE_OTHER\x10\x96\x01\x12\"\n\x1d\x45RROR_DEVICE_NO_WRITE_SUPPORT\x10\x97\x01\x12\x1f\n\x1a\x45RROR_DEVICE_ACCESS_DENIED\x10\x98\x01\x32k\n\x12\x45\x64geControlService\x12U\n\nWriteProps\x12!.mapped.gateway.WritePropsRequest\x1a\".mapped.gateway.WritePropsResponse0\x01\x42I\n\x12\x63om.mapped.gatewayP\x01Z go.mapped.dev/pb/gateway;gateway\xaa\x02\x0eMapped.Gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.gateway.edgecontrol_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.mapped.gatewayP\001Z go.mapped.dev/pb/gateway;gateway\252\002\016Mapped.Gateway'
  _RESULT._serialized_start=730
  _RESULT._serialized_end=1190
  _WRITEPROPSREQUEST._serialized_start=91
  _WRITEPROPSREQUEST._serialized_end=254
  _WRITEPROPSRESPONSE._serialized_start=256
  _WRITEPROPSRESPONSE._serialized_end=370
  _MAPPINGKEYANDVALUE._serialized_start=372
  _MAPPINGKEYANDVALUE._serialized_end=479
  _MAPPINGKEYANDRESULT._serialized_start=482
  _MAPPINGKEYANDRESULT._serialized_end=727
  _EDGECONTROLSERVICE._serialized_start=1192
  _EDGECONTROLSERVICE._serialized_end=1299
# @@protoc_insertion_point(module_scope)
