# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mapped/cloud/types/metadata.proto\x12\x12mapped.cloud.types\"8\n\x0eMetadataRecord\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"K\n\rMetadataValue\x12:\n\x06values\x18\x01 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x06values\"\xc2\x02\n\x0eMetadataUpdate\x12I\n\x08granular\x18\x01 \x01(\x0b\x32+.mapped.cloud.types.MetadataUpdate.GranularH\x00R\x08granular\x12=\n\x07replace\x18\x02 \x01(\x0b\x32!.mapped.cloud.types.MetadataValueH\x00R\x07replace\x1a\x9b\x01\n\x08Granular\x12\x34\n\x03\x61\x64\x64\x18\x01 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x03\x61\x64\x64\x12:\n\x06remove\x18\x02 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x06remove\x12\x1d\n\nremove_all\x18\x03 \x03(\tR\tremoveAllB\x08\n\x06updateBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _METADATARECORD._serialized_start=57
  _METADATARECORD._serialized_end=113
  _METADATAVALUE._serialized_start=115
  _METADATAVALUE._serialized_end=190
  _METADATAUPDATE._serialized_start=193
  _METADATAUPDATE._serialized_end=515
  _METADATAUPDATE_GRANULAR._serialized_start=350
  _METADATAUPDATE_GRANULAR._serialized_end=505
# @@protoc_insertion_point(module_scope)
